import Vue from 'vue'
import Router from 'vue-router'
import Layout from '@/layout'

Vue.use(Router)

// 引入路由
import supplierRoutes from './module/supplier'
import clubRoutes from './module/club'
import personnelRoutes from './module/personnel'
import feedbackRoutes from './module/feedback'
import helperRoutes from './module/helper'
import materialRoutes from './module/material'
import AuditRoutes from './module/audit'
import MemberRoutes from './module/member'
import vipRoutes from './module/vip'
import personalRoutes from './module/personal'
import settingRoutes from './module/settings'
import shareRoutes from './module/share'

// 需要权限访问的路由列表
export const asyncRoutes = [
  ...supplierRoutes,
  ...AuditRoutes,
  ...MemberRoutes,
  ...clubRoutes,
  ...personnelRoutes,
  ...materialRoutes,
  ...feedbackRoutes,
  ...settingRoutes,
  ...helperRoutes,
  ...personalRoutes
]

// 默认路由列表 全部用户都可以访问
export const constantRoutes = [
  ...vipRoutes,
  ...shareRoutes,
  {
    path: '/',
    component: () => import(/* webpackChunkName: "common-page" */ '@/views/index'),
    hidden: true
  },
  {
    path: '/login',
    component: () => import(/* webpackChunkName: "common-page" */ '@/views/common/login'),
    hidden: true
  },
  {
    path: '/password',
    component: Layout,
    name: 'Password',
    meta: { title: '密码管理' },
    hidden: true,
    children: [
      {
        path: 'edit',
        meta: { title: '修改密码' },
        component: () => import(/* webpackChunkName: "common-page" */ '@/views/common/password'),
        hidden: true
      }
    ]
  },
  {
    path: '/proxy',
    component: () => import(/* webpackChunkName: "common-page" */ '@/views/common/proxy'),
    hidden: true
  },
  {
    path: '/test',
    component: () => import('@/views/test')
  },
  {
    path: '/pay',
    component: Layout,
    name: 'PayStatus',
    meta: { title: '支付状态' },
    hidden: true,
    redirect: '/pay/success',
    children: [
      {
        path: 'success',
        component: () => import(/* webpackChunkName: "common-page" */ '@/views/common/payment/success'),
        hidden: true
      },
      {
        path: 'faild',
        component: () => import(/* webpackChunkName: "common-page" */ '@/views/common/payment/faild'),
        hidden: true
      }
    ]
  },
  {
    path: '/login/redirect',
    component: () => import(/* webpackChunkName: "common-page" */ '@/views/common/login/redirect'),
    hidden: true
  },
  {
    path: '/404',
    component: () => import(/* webpackChunkName: "common-page" */ '@/views/common/error-page/404'),
    hidden: true
  },
  {
    path: '/401',
    component: () => import(/* webpackChunkName: "common-page" */ '@/views/common/error-page/401'),
    hidden: true
  },
  // 404页面 放在最后面
  { path: '*', redirect: '/404', hidden: true }
]

// 创建路由对象
const createRouter = () =>
  new Router({
    scrollBehavior: () => ({ y: 0 }),
    routes: constantRoutes
  })

const router = createRouter()

// 重置路由
export function resetRouter() {
  const newRouter = createRouter()
  router.matcher = newRouter.matcher // reset router
}

export default router
