import { constantRoutes, asyncRoutes } from '@/router/index'
import store from '@/store'
import routerMap from '@/router/router-map'

let routesTree = []
let routes = []
let routeMap = []

// 获取全部路由信息
function getRoutes() {
  routes = [...constantRoutes, ...asyncRoutes].filter(item => item.meta)
  if (!store.getters.roles.includes('admin')) {
    routes = routes.filter(route => !route.meta.roles || route.meta.roles.includes('normal'))
  }
  return routes
}

// 从路由map中获取id
function getRouteKeyFromMap(name, flag = false) {
  if (flag) {
    return routerMap.reduce((prev, item) => {
      prev.push(...item.children)
      return prev
    }, []).find(item => item.name === name)?.id
  } else {
    return routerMap.find(item => item.name === name)?.id
  }
}

function formatRoutesToModule() {
  routes = getRoutes()
  routesTree = []
  routeMap = []
  routes.forEach(first => {
    const obj = {
      label: first.meta.title,
      value: getRouteKeyFromMap(first.meta.title, false)
    }
    // 提取当前登录用户可以看到的路由
    const find = routerMap.find(item => item.name === first.meta.title)
    if (find) {
      routeMap.push(find)
    }
    if (first.children) {
      obj.children = []
      first.children.forEach(second => {
        obj.children.push({
          label: second.meta.title,
          value: getRouteKeyFromMap(second.meta.title, true)
        })
      })
    }
    routesTree.push(obj)
  })
  return routesTree
}

export function getToutesTree() {
  return formatRoutesToModule()
}

// 根据id获取栏目
export function getModuleType(ids) {
  ids = ids.split('-')
  console.log(routeMap)
  const parent = routeMap.find(item => {
    console.log(item)
    return item.id === parseInt(ids[0])
  })
  const children = parent && parent.children.find(item => item.id === parseInt(ids[1]))
  if (!parent || !children) {
    return store.getters.roles.includes('admin') ? '未知模块' : ''
  }
  return `${parent.name}/${children.name}`
}
